@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Change Display
 
 Demonstrates migrating a window between different displays and
@@ -23,6 +23,8 @@ This is a moderately complex example, and demonstrates:
 - Using GtkListStore and GtkTreeView
 - Using GtkDialog
 '''
+import pygtk
+pygtk.require('2.0')
 import gtk
 import gobject
 
