@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Entry Completion
 
 GtkEntryCompletion provides a mechanism for adding support for
@@ -6,6 +6,8 @@ completion in GtkEntry.
 '''
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
+import pygtk
+pygtk.require('2.0')
 import gtk
 
 class EntryCompletionDemo(gtk.Dialog):
