@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Expander
 
 GtkExpander allows to provide additional content that is initially hidden.
@@ -6,6 +6,8 @@ This is also known as "disclosure triangle".
 '''
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
+import pygtk
+pygtk.require('2.0')
 import gtk
 
 class ExpanderDemo(gtk.Dialog):
