@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Text Widget/Hypertext
 
 Usually, tags modify the appearance of text in the view, e.g. making it
@@ -7,6 +7,8 @@ They can also affect the behavior of mouse and key presses, as this demo
 shows.'''
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
+import pygtk
+pygtk.require('2.0')
 import gtk
 import pango
 
