@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Images
 
 GtkImage is used to display an image; the image can be in a number of formats.
@@ -11,6 +11,9 @@ depend on loading external files, your application binary can be self-contained.
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
 import os
+
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
