@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Status Icon
 
 This is a simple example that shows how to create a status icon that
@@ -7,6 +7,8 @@ in Windows.
 '''
 ## Author: Nikos Kouremenos
 
+import pygtk
+pygtk.require('2.0')
 import gtk
 
 
