@@ -1,10 +1,12 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 """Text Widget/Automatic scrolling
 
 This example demonstrates how to use the gravity of
 GtkTextMarks to keep a text view scrolled to the bottom
 while appending text."""
 
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
