@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 """Text Widget/TextView
 
 The GtkTextView widget displays a GtkTextBuffer. One GtkTextBuffer can be displayed
@@ -9,6 +9,8 @@ shows off the widget's text formatting features."""
 import os
 import sys
 
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
