@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''Tree View/Tree Store
 
 The GtkTreeStore is used to store data in tree form, to be used
@@ -7,6 +7,8 @@ GtkTreeStore and displays it. If you're new to the GtkTreeView widgets
 and associates, look into the GtkListStore example first.'''
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
