@@ -1,4 +1,4 @@
-#!/usr/local/bin/python2.6
+#!/usr/local/bin/python2.7
 '''UI Manager
 
 The GtkUIManager object allows the easy creation of menus
@@ -6,6 +6,8 @@ from an array of actions and a description of the menu hierarchy.
 '''
 # pygtk version: Maik Hertha <maik.hertha@berlin.de>
 
+import pygtk
+pygtk.require('2.0')
 import gobject
 import gtk
 
